<?php

namespace Drupal\webform_modal\Controller;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\RendererInterface;
use Drupal\webform\Entity\Webform;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Response;

/**
 * Controller for the Webform modal.
 */
class WebformModalController extends ControllerBase {

  /**
   * The configuration service.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs a new WebformModalController.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration service.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   The renderer service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, RendererInterface $renderer) {
    $this->configFactory = $config_factory;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    // Instantiate the controller and inject services.
    return new static(
      $container->get('config.factory'),
      $container->get('renderer')
    );
  }

  /**
   * Displays the Webform modal using the webform ID from the configuration.
   */
  public function webformModal() {
    $config = $this->configFactory->get('webform_modal.settings');
    $webform_id = $config->get('webform_id');

    if (empty($webform_id)) {
      return new Response('No webform selected in configuration.', 400);
    }

    $webform = Webform::load($webform_id);

    if ($webform) {
      $submission_form = $webform->getSubmissionForm();

      $webform_output = $this->renderer->render($submission_form);

      $webform_elements = $webform->getElementsDecoded();

      return [
        '#theme' => 'webform_modal_template',
        '#content' => [
          'webform_output' => $webform_output,
          'webform_title' => $webform->label(),
          'webform_fields' => $webform_elements,
        ],
        '#attached' => [
          'library' => [
            'webform/webform.ajax',
          ],
        ],
      ];
    }
    else {
      return new Response('Webform not found.', 404);
    }
  }

}
